# release-feed-mediola

A tool that generates Atom feeds for software updates of
[Mediola](https://www.mediola.com/) products.

Not affiliated with Mediola – connected living AG.

## Installation

### Installing from PyPI

To install `release-feed-mediola` from PyPI, open a shell and run:

```shell
pip install release_feed_mediola
```

If that doesn’t work, try:

```shell
python3 -m pip install release_feed_mediola
```

### Installing from the AUR

Direct your favorite
[AUR helper](https://wiki.archlinux.org/title/AUR_helpers) to the
`release-feed-mediola` package.

## Usage

To generate an Atom feed for a given Mediola product, run
`release-feed-mediola` with the product name as an argument.

To see a list of supported Mediola products, run
`release-feed-mediola` without arguments.

## Updating your feed automatically with systemd

You may want to run `release-feed-mediola` periodically to generate
and update a feed file using a systemd timer and service.
This requires a Linux system and systemd version 256 or newer.

### Installing the unit files

First, install the systemd timer and service unit files.

- If you have installed `release-feed-mediola` from the AUR, the
  unit files have already been installed.

- Otherwise, download the unit files `release-feed-mediola@.service`
  and `release-feed-mediola@.timer` from the `contrib/systemd`
  directory on the GitHub repository. Place the files into your
  `/etc/systemd/user/` directory. You may have to edit the
  paths inside the `ExecStart` directive to match your Linux distro.

### Enabling the timer

To enable the systemd timer for a given Mediola product, run:

```shell
# Replace PRODUCT with the Mediola product name you want to track
systemctl --user enable --now release-feed-mediola@PRODUCT.timer
```

You can enable and run multiple timers for different Mediola
products at the same time.

Each service will generate one `feed.atom` file per product once a
day.

### Setting up your feed reader

For each product you want to track, locate the generated `feed.atom`
file in the `~/.local/share/feeds/release-feed-mediola/` directory
hierarchy. Point your feed reader software to that file.

You may want to use a `file:///` URL if your reader doesn’t support
feeds from the local filesystem directly. For example:

> `file:///home/yourusername/.local/share/feeds/release-feed-mediola/neo/feed.atom`

### Disabling the timer

To disable the systemd timer for a given Mediola product, run:

```shell
# Replace PRODUCT with the Mediola product name you want to track
systemctl --user disable --now release-feed-mediola@PRODUCT.timer
```

## Contributing to release-feed-mediola

See [`CONTRIBUTING.md`](https://github.com/claui/release-feed-mediola/blob/main/CONTRIBUTING.md).

## Legal notice

This tool and repository are not affiliated with Mediola – connected
living AG. Products mentioned in the Atom feed generated by this
tool may be subject to Mediola’s end-user license agreement (EULA).
For your convenience, each entry of the generated feed includes a
link to that EULA.

## License

Copyright (c) 2022 – 2024 Claudia Pellegrino

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
For a copy of the License, see [LICENSE](LICENSE).
